#ifndef NT2_INCLUDE_FUNCTIONS_ELLIE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ELLIE_HPP_INCLUDED

#include <nt2/elliptic/include/functions/ellie.hpp>

#endif
